pub struct KVCache { /* private fields */ }Expand description
KV cache for a single model.
Pre-allocates buffers for the maximum sequence length to avoid allocations during generation.
Implementations
Sourceimpl KVCache
impl KVCache
Sourcepub fn new(num_layers: usize, num_kv_heads: usize, head_dim: usize) -> Self
pub fn new(num_layers: usize, num_kv_heads: usize, head_dim: usize) -> Self
Create a new empty KV cache.
Sourcepub fn with_capacity(
num_layers: usize,
num_kv_heads: usize,
head_dim: usize,
max_seq_len: usize,
) -> Self
pub fn with_capacity( num_layers: usize, num_kv_heads: usize, head_dim: usize, max_seq_len: usize, ) -> Self
Create a new KV cache with pre-allocated capacity.
Sourcepub fn append(&mut self, layer: usize, k_data: &[f32], v_data: &[f32])
pub fn append(&mut self, layer: usize, k_data: &[f32], v_data: &[f32])
Append K and V vectors for the current token to a specific layer.
k_data and v_data should each have length num_kv_heads * head_dim.
Sourcepub fn advance(&mut self)
pub fn advance(&mut self)
Advance the sequence position by one token. Call this after appending K/V data to all layers.
Sourcepub fn k(&self, layer: usize) -> &[f32]
pub fn k(&self, layer: usize) -> &[f32]
Get the full K cache for a layer: [len * num_kv_heads * head_dim].
Sourcepub fn v(&self, layer: usize) -> &[f32]
pub fn v(&self, layer: usize) -> &[f32]
Get the full V cache for a layer: [len * num_kv_heads * head_dim].
Sourcepub fn num_layers(&self) -> usize
pub fn num_layers(&self) -> usize
Number of layers.
Sourcepub fn entry_size(&self) -> usize
pub fn entry_size(&self) -> usize
Entry size (num_kv_heads * head_dim) per token per layer.